@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 13's 2.6.34 kernel.
+# This is a kernel build script for Fedora 14's 2.6.35 kernel.
 #
 
 die () {
@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.34.9-69.fc13.src.rpm ]
+if [ ! -r kernel-2.6.35.14-97.fc14.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/13/SRPMS/kernel-2.6.34.9-69.fc13.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/14/SRPMS/kernel-2.6.35.14-97.fc14.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.34.9-69.fc13.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.34.9-69.fc13.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.35.14-97.fc14.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.35.14-97.fc14.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20110929.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20111025.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20110929.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20110929.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20111025.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20111025.tar.gz' || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
@@ -33,11 +33,11 @@ patch << "EOF" || die "Can't patch spec file."
  # (Uncomment the '#' and both spaces below to set the buildid.)
  #
 -# % define buildid .local
-+%define buildid _tomoyo_1.8.3
++%define buildid _tomoyo_1.8.3p1
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
-@@ -409,6 +409,11 @@
+@@ -424,6 +424,11 @@
  # to versions below the minimum
  #
  
@@ -49,7 +49,7 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -471,7 +476,7 @@
+@@ -483,7 +488,7 @@
  AutoProv: yes\
  %{nil}
  
@@ -58,27 +58,27 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -962,7 +967,7 @@
- Provides: kernel-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
+@@ -988,7 +993,7 @@
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
+ Requires: perl\
 -%description -n kernel%{?variant}%{?1:-%{1}}-devel\
 +%description -n ccs-kernel%{?variant}%{?1:-%{1}}-devel\
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1631,6 +1636,10 @@
+@@ -1667,6 +1672,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20110929.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.34-fedora-13.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20111025.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.35-fedora-14.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1659,6 +1668,9 @@
+@@ -1695,6 +1704,9 @@
  for i in *.config
  do
    mv $i .config
@@ -99,18 +99,5 @@ echo ""
 ARCH=`uname -m`
 echo "I'll start 'rpmbuild -bb --target $ARCH --with baseonly --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
 sleep 30
-patch << "EOF" || die "Can't patch spec file."
---- /root/rpmbuild/SPECS/ccs-kernel.spec
-+++ /root/rpmbuild/SPECS/ccs-kernel.spec
-@@ -221,7 +221,7 @@
- 
- # kernel-PAE is only built on i686.
- %ifarch i686
--%define with_pae 1
-+%define with_pae 0
- %else
- %define with_pae 0
- %endif
-EOF
 exec rpmbuild -bb --target $ARCH --with baseonly --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec
 exit 0
